Module user — Inmanta 2017.3dev documentation

# Module user

> - License: ASL 2
> - Version: 0.1.1
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/user.git

## Entities

entity `user::Group`

  Parents: `std::ManagedResource`, `std::PurgeableResource`

  attribute string `name`
  attribute bool `system`=False
  relation std::Host `host` [1]

  The following implementations are defined for this entity:

  > - `user::execGroup`

  The following implements statements select implementations for this entity:

  > - `user::execGroup`

entity `user::User`

  Parents: `std::ManagedResource`, `std::PurgeableResource`

  attribute string `homedir`
  attribute string `name`
  attribute string `groups`=List()
  attribute string `shell`='/bin/bash'
  attribute bool `system`=False
  attribute string `group`
  relation std::Host `host` [1]

  The following implementations are defined for this entity:

  > - `user::execUser`

  The following implements statements select implementations for this entity:

  > - `user::execUser`

## Implementations

implementation `user::execGroup`

  Exec based implementation until a handler is available

implementation `user::execUser`

  Exec based implementation until a handler is available